/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Thunderbird Conversations
 *
 * The Initial Developer of the Original Code is
 *  Jonathan Protzenko <jonathan.protzenko@gmail.com>
 * Portions created by the Initial Developer are Copyright (C) 2010
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
 
/**
 * Python-style range function to use in list comprehensions.
 *  @param {Number} begin 
 *  @param {Number} end 
 *  @return {Iterator} An iterator that yields from begin to end - 1.
 */
function range(begin, end) {
  for (let i = begin; i < end; ++i) {
    yield i;
  }
}

/**
 * Wraps the low-level header parser stuff.
 * @param {String} aMimeLine a line that looks like "John &lt;john@cheese.com&gt;, Jane &lt;jane@wine.com&gt;"
 * @param {Boolean} aDontFix (optional) Default to false. Shall we return an
 *  empty array in case aMimeLine is empty?
 * @return {Array} a list of { email, name } objects
 */
function parseMimeLine (aMimeLine, aDontFix) {
  let emails = {};
  let fullNames = {};
  let names = {};
	let msgHeaderParser = Components.classes['@mozilla.org/messenger/headerparser;1'].
														getService(Components.interfaces.nsIMsgHeaderParser);
  let numAddresses = msgHeaderParser.parseHeadersWithArray(aMimeLine,
																		 emails,
																		 names,
																		 fullNames);
  if (numAddresses)
    return [{ email: emails.value[i], name: names.value[i], fullName: fullNames.value[i] }
      for each (i in range(0, numAddresses))];
  else if (aDontFix)
    return [];
  else
    return [{ email: "", name: "-", fullName: "-" }];
}

Components.utils.import("resource:///modules/composeUtils.js");

function quoteMsgHdrForQuickReply(aMsgHdr, aMsgURI, aIdentity, aTextArea, aQuoteMsgHdrForQuickReply, aEditDiv) {
	quoteMsgHdr(aMsgHdr, aMsgURI, msgWindow, function (aBody) {
		// Join together the different parts
		let date = (new Date(aMsgHdr.date/1000)).toLocaleString();
		let [{ email, name }] = parseMimeLine(aMsgHdr.mime2DecodedAuthor);
		let author = name || email;
		// This will somehow make sure reflow inside the blockquotes happens,
		// rather than trying to use our own citeString function which doesn't
		// perform rewrap.
		let body = "\n"
			+ htmlToPlainText('<blockquote type="cite">'+aBody+'</blockquote>')
				.trim();
		let sbs = Components.classes["@mozilla.org/intl/stringbundle;1"].
							getService(Components.interfaces.nsIStringBundleService);
		let sComposeMsgsBundle = sbs.createBundle("chrome://messenger/locale/messengercompose/composeMsgs.properties");
		let quoteblock = // body already starts with a newline
			sComposeMsgsBundle.formatStringFromName("quoteIntroString", [author], 1) + body;
		// Grab the identity we're using and use its parameters.
		let identity = aIdentity;
		// The user might be fast and might have started typing something
		// already
		let node = aTextArea;
		let txt = node.value;
		let val = null;
		let pos = null;
		let quote = identity.autoQuote
			? quoteblock
			: "";
		// Assemble the parts
		if (identity.replyOnTop) {
			quote = "\n\n" + quote;
			pos = 0;
			val = txt + quote;
		} else {
			quote = quote + "\n\n";
			pos = (quote + txt).length;
			val = quote + txt;
		}
		// After we removed any trailing newlines, insert it into the textarea
		node.value = val;
		// I <3 HTML5 selections.
		node.selectionStart = pos;
		node.selectionEnd = pos;
		
		adjustQuickReplyBoxHeight(aTextArea, aEditDiv);
		aQuoteMsgHdrForQuickReply.scrollIntoView(true);
	});
}
